@@ -1,11 +1,19 @@
 //! `rustix` provides efficient memory-safe and [I/O-safe] wrappers to
-//! POSIX-like, Unix-like, Linux, and Winsock syscall-like APIs, with
+//! POSIX-like, Unix-like, Linux, and Winsock2 syscall-like APIs, with
 //! configurable backends.
 //!
-//! For example, instead of calling libc directly, using an `unsafe` block,
-//! passing a raw file descriptor, passing a raw pointer, passing a buffer
-//! length, manually checking the return value for errors, and manually
-//! converting the return value to the intended type:
+//! With rustix, you can write code like this:
+//!
+//! ```rust
+//! # fn read(sock: std::net::TcpStream, buf: &mut [u8]) -> std::io::Result<()> {
+//! # use rustix::net::RecvFlags;
+//! let nread: usize = rustix::net::recv(&sock, buf, RecvFlags::PEEK)?;
+//! # let _ = nread;
+//! # Ok(())
+//! # }
+//! ```
+//!
+//! instead of like this:
 //!
 //! ```rust
 //! # fn read(sock: std::net::TcpStream, buf: &mut [u8]) -> std::io::Result<()> {
@@ -30,18 +38,6 @@
 //! # }
 //! ```
 //!
-//! With rustix you can call a safe function, pass it any type that implements
-//! [`AsFd`], pass it a slice, and get a `Result` carrying the intended type:
-//!
-//! ```rust
-//! # fn read(sock: std::net::TcpStream, buf: &mut [u8]) -> std::io::Result<()> {
-//! # use rustix::net::RecvFlags;
-//! let nread: usize = rustix::net::recv(&sock, buf, RecvFlags::PEEK)?;
-//! # let _ = nread;
-//! # Ok(())
-//! # }
-//! ```
-//!
 //! rustix's APIs perform the following tasks:
 //!  - Error values are translated to [`Result`]s.
 //!  - Buffers are passed as Rust slices.
@@ -73,7 +69,6 @@
 //! [`cap-std`]: https://crates.io/crates/cap-std
 //! [`system-interface`]: https://crates.io/crates/system-interface
 //! [`io-streams`]: https://crates.io/crates/io-streams
-//! [`std`]: https://doc.rust-lang.org/std/
 //! [`getrandom`]: https://crates.io/crates/getrandom
 //! [`bitflags`]: https://crates.io/crates/bitflags
 //! [`AsFd`]: https://doc.rust-lang.org/stable/std/os/unix/io/trait.AsFd.html
@@ -97,8 +92,8 @@
 #![cfg_attr(not(feature = "std"), feature(slice_internals))]
 #![cfg_attr(not(feature = "std"), feature(toowned_clone_into))]
 #![cfg_attr(not(feature = "std"), feature(vec_into_raw_parts))]
-#![cfg_attr(feature = "rustc-dep-of-std", feature(const_raw_ptr_deref))]
 #![cfg_attr(feature = "rustc-dep-of-std", feature(core_intrinsics))]
+#![cfg_attr(feature = "rustc-dep-of-std", feature(ip))]
 #![cfg_attr(
     all(not(feature = "rustc-dep-of-std"), core_intrinsics),
     feature(core_intrinsics)
@@ -149,7 +144,6 @@ pub mod thread;
 pub mod time;
 
 #[cfg(not(windows))]
-#[cfg(linux_raw)]
 #[doc(hidden)]
 pub mod runtime;
 
