@@ -5,7 +5,6 @@ use crate::{imp, io};
 mod auxv;
 #[cfg(not(target_os = "wasi"))]
 mod chdir;
-mod exit;
 #[cfg(not(target_os = "wasi"))] // WASI doesn't have get[gpu]id.
 mod id;
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
@@ -44,15 +43,14 @@ pub use auxv::{linux_execfn, linux_hwcap};
 pub use chdir::chdir;
 #[cfg(not(any(target_os = "wasi", target_os = "fuchsia")))]
 pub use chdir::fchdir;
-#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
+#[cfg(not(target_os = "wasi"))]
 pub use chdir::getcwd;
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
-pub use exit::exit_group;
-#[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
 pub use id::Cpuid;
 #[cfg(not(target_os = "wasi"))]
 pub use id::{
-    getegid, geteuid, getgid, getpid, getppid, getuid, Gid, Pid, RawGid, RawPid, RawUid, Uid,
+    getegid, geteuid, getgid, getpid, getppid, getuid, Gid, Pid, RawGid, RawNonZeroPid, RawPid,
+    RawUid, Uid,
 };
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
 pub use membarrier::{
@@ -125,15 +123,23 @@ pub fn sched_yield() {
     imp::syscalls::sched_yield()
 }
 
-/// `waitpid`—Wait for a specific process to change state.
+/// `waitpid(pid, waitopts)`—Wait for a specific process to change state.
 ///
-/// If the selected PID is `Pid::NONE`, the call will wait for the child
-/// process, whose PID matches that of the calling process.
+/// If the pid is `None`, the call will wait for any child process whose
+/// process group id matches that of the calling process.
+///
+/// If the pid is equal to `RawPid::MAX`, the call will wait for any child
+/// process.
+///
+/// Otherwise if the `wrapping_neg` of pid is less than pid, the call will wait
+/// for any child process with a group ID equal to the `wrapping_neg` of `pid`.
+///
+/// Otherwise, the call will wait for the child process with the given pid.
 ///
 /// On Success, returns the status of the selected process.
 ///
-/// If `NOHANG` was specified in the options,
-/// and the selected child process didn't change state, returns `None`.
+/// If `NOHANG` was specified in the options, and the selected child process
+/// didn't change state, returns `None`.
 ///
 /// # References
 ///  - [POSIX]
@@ -143,17 +149,18 @@ pub fn sched_yield() {
 /// [Linux]: https://man7.org/linux/man-pages/man2/waitpid.2.html
 #[cfg(not(target_os = "wasi"))]
 #[inline]
-pub fn waitpid(pid: Pid, waitopts: WaitOptions) -> io::Result<Option<WaitStatus>> {
-    Ok(imp::syscalls::waitpid(pid.as_raw(), waitopts)?.map(|(_, status)| status))
+pub fn waitpid(pid: Option<Pid>, waitopts: WaitOptions) -> io::Result<Option<WaitStatus>> {
+    Ok(imp::syscalls::waitpid(pid, waitopts)?.map(|(_, status)| status))
 }
 
-/// `wait`—Wait for any of the children of calling process to change state.
+/// `wait(waitopts)`—Wait for any of the children of calling process to
+/// change state.
 ///
-/// On success, returns the pid of the child process whose state changed,
-/// and the status of said process.
+/// On success, returns the pid of the child process whose state changed, and
+/// the status of said process.
 ///
-/// If `NOHANG` was specified in the options,
-/// and no child process changed state, returns `None`.
+/// If `NOHANG` was specified in the options, and the selected child process
+/// didn't change state, returns `None`.
 ///
 /// # References
 ///  - [POSIX]
@@ -164,5 +171,5 @@ pub fn waitpid(pid: Pid, waitopts: WaitOptions) -> io::Result<Option<WaitStatus>
 #[cfg(not(target_os = "wasi"))]
 #[inline]
 pub fn wait(waitopts: WaitOptions) -> io::Result<Option<(Pid, WaitStatus)>> {
-    imp::syscalls::waitpid(!0, waitopts)
+    imp::syscalls::wait(waitopts)
 }
